@@ -175,18 +175,19 @@ Glib::RefPtr<Gnome::Gda::DataModel> Base_DB::query_execute(const Glib::ustring&
   {
     Glib::RefPtr<Gnome::Gda::Connection> gda_connection = sharedconnection->get_gda_connection();
 
-    /*
-    try
-    {
-      std::cout << "Debug: query_execute():  " << strQuery << std::endl;
+   const App_Glom* app = App_Glom::get_application();
+   if(app && app->get_show_sql_debug())
+   {
+      try
+      {
+        std::cout << "Debug: query_execute():  " << strQuery << std::endl;
+      }
+      catch(const Glib::Exception& ex)
+      {
+        std::cout << "Debug: query string could not be converted to std::cout: " << ex.what() << std::endl;
+      }
     }
-    catch(const Glib::Exception& ex)
-    {
-      std::cout << "Debug: query string could not be converted to std::cout: " << ex.what() << std::endl;
-    }
-    */
     
-
     result = gda_connection->execute_single_command(strQuery);
     if(!result)
     {
@@ -1379,7 +1380,7 @@ Glib::ustring Base_DB::get_find_where_clause_quick(const Glib::ustring& table_na
 
       if(use_this_field)
       {
-        strClausePart = table_name + "." + field->get_name() + " " + field->sql_find_operator() + " " +  field->sql_find(quick_search);
+        strClausePart = "\"" + table_name + "\".\"" + field->get_name() + "\" " + field->sql_find_operator() + " " +  field->sql_find(quick_search);
       }
 
       if(!strClausePart.empty())
