@@ -26,6 +26,7 @@
 #include <libgnome/gnome-init.h> // For gnome_program_init().
 #include <libgnomevfsmm/uri.h>
 #include <libgnomecanvasmm.h>
+#include <gtksourceviewmm/init.h>
 #include <glibmm/i18n.h>
 
 
@@ -34,21 +35,25 @@
 
 #include "application.h"
 
+namespace Glom
+{
 
-class ExampleOptionGroup : public Glib::OptionGroup
+class OptionGroup : public Glib::OptionGroup
 { 
 public:
-  ExampleOptionGroup();
+  OptionGroup();
 
   //These int instances should live as long as the OptionGroup to which they are added, 
   //and as long as the OptionContext to which those OptionGroups are added.
   std::string m_arg_filename;
   bool m_arg_version;
+  bool m_arg_debug_sql;
 };
 
-ExampleOptionGroup::ExampleOptionGroup()
+OptionGroup::OptionGroup()
 : Glib::OptionGroup("Glom", _("Glom options"), _("Command-line options for glom")),
-  m_arg_version(false)
+  m_arg_version(false),
+  m_arg_debug_sql(false)
 {
   Glib::OptionEntry entry;
   entry.set_long_name("file");
@@ -61,8 +66,14 @@ ExampleOptionGroup::ExampleOptionGroup()
   entry_version.set_short_name('V');
   entry_version.set_description(_("The version of this application."));
   add_entry(entry_version, m_arg_version);
+
+  Glib::OptionEntry entry_debug_sql;
+  entry_version.set_long_name("debug_sql");
+  entry_version.set_description(_("Show the generated SQL queries on stdout, for debugging."));
+  add_entry(entry_version, m_arg_debug_sql);
 }
 
+} //namespace Glom
 
 int 
 main(int argc, char* argv[])
@@ -73,10 +84,11 @@ main(int argc, char* argv[])
   textdomain(GETTEXT_PACKAGE);
 
   Gnome::Gda::init("glom", VERSION, argc, argv);
+  gtksourceview::init();
 
   Glib::OptionContext context;
 
-  ExampleOptionGroup group;
+  Glom::OptionGroup group;
   context.set_main_group(group);
 
   try
@@ -102,7 +114,7 @@ main(int argc, char* argv[])
   try
   {
     //Initialize gnome_program, so that we can use gnome_help_display().    
-    gnome_program_init(PACKAGE_NAME, PACKAGE_VERSION, LIBGNOME_MODULE, argc, argv,
+    gnome_program_init(PACKAGE, VERSION, LIBGNOME_MODULE, argc, argv,
         GNOME_PARAM_HUMAN_READABLE_NAME, _("Glom"),
         GNOME_PROGRAM_STANDARD_PROPERTIES, NULL);
 
@@ -136,10 +148,11 @@ main(int argc, char* argv[])
 
     // Main app
     Glib::RefPtr<Gnome::Glade::Xml> refXml = Gnome::Glade::Xml::create(GLOM_GLADEDIR "glom.glade", "window_main");
-    App_Glom* pApp_Glom = 0;
+    Glom::App_Glom* pApp_Glom = 0;
     refXml->get_widget_derived("window_main", pApp_Glom);
 
     pApp_Glom->set_command_line_args(argc, argv);
+    pApp_Glom->set_show_sql_debug(group.m_arg_debug_sql);
 
     bool test = pApp_Glom->init(input_uri); //Sets it up and shows it.
     if(test) //The user could cancel the offer of a new or existing database.
