@@ -22,9 +22,12 @@
 #define GLOM_UTILITY_WIDGETS_COMBO_GLOM_CHOICESBASE_H
 
 #include <gtkmm.h>
-#include "../data_structure/field.h"
+#include <glom/libglom/data_structure/field.h>
 #include "layoutwidgetfield.h"
 
+namespace Glom
+{
+
 class ComboGlomChoicesBase : public LayoutWidgetField
 {
 public:
@@ -65,5 +68,7 @@ protected:
   //Gnome::Gda::Value m_value; //The last-stored value. We have this because the displayed value might be unparseable.
 };
 
+} //namespace Glom
+
 #endif //GLOM_UTILITY_WIDGETS_COMBO_GLOM_CHOICESBASE_H
 
